@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::KENTNL;
 BEGIN {
-  $Dist::Zilla::PluginBundle::KENTNL::VERSION = '0.01002610';
+  $Dist::Zilla::PluginBundle::KENTNL::VERSION = '0.01006912';
 }
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
@@ -17,10 +17,14 @@ use namespace::autoclean -also => [qw( _expand _load _defined_or _only_git _only
 
 
 
-
 sub _expand {
   my ( $class, $suffix, $conf ) = @_;
   ## no critic ( RequireInterpolationOfMetachars )
+  if ( ref $suffix ) {
+    my ( $corename, $rename ) = @{$suffix};
+    return [ q{@KENTNL/} . $corename . q{/} . $rename, 'Dist::Zilla::Plugin::' . $corename, $conf ];
+
+  }
   return [ q{@KENTNL/} . $suffix, 'Dist::Zilla::Plugin::' . $suffix, $conf ];
 }
 
@@ -53,19 +57,20 @@ sub _mk_only {
   my ( $subname, $envname, $argfield ) = @_;
   my $sub = sub {
     my ( $args, @rest ) = @_;
-    return () if exists $ENV{'KENTNL_NO' . $envname};
+    return () if exists $ENV{ 'KENTNL_NO' . $envname };
     return @rest unless defined $args;
     return @rest unless ref $args eq 'HASH';
-    return @rest unless exists $args->{'no' .  $argfield};
+    return @rest unless exists $args->{ 'no' . $argfield };
     return ();
   };
   {
     ## no critic (ProhibitNoStrict)
     no strict 'refs';
-    *{__PACKAGE__ . '::_only_' . $subname} = $sub;
+    *{ __PACKAGE__ . '::_only_' . $subname } = $sub;
   }
   return 1;
 }
+
 BEGIN {
   _mk_only(qw( git GIT git ));
   _mk_only(qw( cpan CPAN cpan ));
@@ -112,10 +117,10 @@ sub bundle_config {
         time_zone => _defined_or( $arg, version_rel_time_zone => 'Pacific/Auckland' ),
       }
     ],
-    [ 'GatherDir'             => {} ],
-    [ 'MetaConfig'            => {} ],
-    [ 'PruneCruft'            => {} ],
-    _only_git( $arg , [ 'GithubMeta'            => {} ] ),
+    [ 'GatherDir'  => {} ],
+    [ 'MetaConfig' => {} ],
+    [ 'PruneCruft' => {} ],
+    _only_git( $arg, [ 'GithubMeta' => {} ] ),
     [ 'License'               => {} ],
     [ 'PkgVersion'            => {} ],
     [ 'PodWeaver'             => {} ],
@@ -135,9 +140,7 @@ sub bundle_config {
     [ 'ReportVersions::Tiny'  => {} ],
     [ 'KwaliteeTests'         => {} ],
     [ 'PortabilityTests'      => {} ],
-    [ 'EOLTests'              => {
-        trailing_whitespace => 1,
-    } ],
+    [ 'EOLTests'              => { trailing_whitespace => 1, } ],
     [ 'ExtraTests'            => {} ],
     [ 'TestRelease'           => {} ],
     [ 'ConfirmRelease'        => {} ],
@@ -148,10 +151,12 @@ sub bundle_config {
         _release_fail($arg),
         _only_git( $arg, [ 'Git::Check' => { filename => 'Changes' } ] ),
         [ 'NextRelease' => {} ],
-        _only_git( $arg, [ 'Git::Tag' => { filename => 'Changes', tag_format => '%v-source' } ] ),
+        _only_git( $arg, [ [ 'Git::Tag', 'tag_master' ] => { filename => 'Changes', tag_format => '%v-source' } ] ),
         _only_git( $arg, [ 'Git::Commit' => {} ] ),
+        _only_git( $arg, [ 'Git::CommitBuild' => { release_branch => 'releases' } ] ),
+        _only_git( $arg, [ [ 'Git::Tag', 'tag_release' ] => { filename => 'Changes', tag_format => '%v' } ] ),
         _only_cpan( $arg, [ 'UploadToCPAN' => {} ] ),
-        _only_cpan( $arg, _only_twitter( $arg, [ 'Twitter'      => {} ] ) ),
+        _only_cpan( $arg, _only_twitter( $arg, [ 'Twitter' => {} ] ) ),
       ]
     )
   );
@@ -174,7 +179,7 @@ Dist::Zilla::PluginBundle::KENTNL - BeLike::KENTNL when you build your distribut
 
 =head1 VERSION
 
-version 0.01002610
+version 0.01006912
 
 =head1 SYNOPSIS
 
@@ -193,7 +198,7 @@ and wants others to be using what he's using if they want to be doing work on hi
 
 =head2 bundle_config
 
-See L<Dist::Zilla::Role::PluginBundle> for what this is for, it is a method to satisfy that role.
+See L<< the C<PluginBundle> role|Dist::Zilla::Role::PluginBundle >> for what this is for, it is a method to satisfy that role.
 
 =head1 ENVIRONMENT
 
@@ -217,7 +222,7 @@ same as release_fail=1
 
 =head1 AUTHOR
 
-  Kent Fredric <kentnl@cpan.org>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
